/*
 * @Author: seimin
 * @Date: 2024-09-24 16:34:47
 * @LastEditors: seimin
 * @LastEditTime: 2024-09-26 11:09:46
 * @Description: 来电弹屏websocket服务
 */
import { Injectable } from "@angular/core";
import { Observable } from "rxjs";
import { WebsocketPhoneService } from './websocket-phone.service';
import { WebsocketHjzxService } from './websocket-hjzx.service';
import { MainService } from './main.service';
import http from "../../assets/js/http";

@Injectable({
  providedIn: "root",
})
export class WebsocketIncomingService {
  constructor(
    private mainService: MainService,
    private phoneService: WebsocketPhoneService,
    private hjzxService: WebsocketHjzxService,
  ) { }

  // 连接websocket { userCount }
  private user = JSON.parse(localStorage.getItem("user")); //用户信息
  connectWs(): Observable<any> {
    let userCount = this.user.user.account + "|" + this.getPhoneNumber();
    if(this.getSign() === 'box'){
      return this.phoneService.connectWs(http.phoneWs, { userCount });
    }else if(this.getSign() === 'callCenter'){
      return this.hjzxService.connectWs(this.getSocketUrl(), { userCount });
    }
  }
  // 断开websocket
  closeWs(flag: boolean = false) {
    console.log('sign', this.getSign())
    if(this.getSign() === 'box'){
      this.phoneService.closeWs(flag);
    }else if(this.getSign() === 'callCenter'){
      this.hjzxService.closeWs(flag);
    }
  }

  // 绑定的分机号码
  private phoneNumber:string = '';
  // 获取绑定分机号码
  getPhoneNumber() {
    return this.phoneNumber || localStorage.getItem('phoneNumber');
  }
  // 设置绑定分机号码
  setPhoneNumber(phoneNumber: string) {
    this.phoneNumber = phoneNumber;
    localStorage.setItem('phoneNumber', phoneNumber);
  }
  // 删除绑定分机号码
  removePhoneNumber() {
    this.phoneNumber = '';
    localStorage.removeItem('phoneNumber');

    this.removeSign();
    this.removeSocketUrl();
  }

  // 标识(呼叫中心或录音盒)
  // callCenter|box
  private sign:string = '';
  // 获取绑定标识
  getSign() {
    return this.sign || localStorage.getItem('sign');
  }
  // 设置绑定标识
  setSign(sign: string) {
    this.sign = sign;
    localStorage.setItem('sign', sign);
  }
  // 删除绑定标识
  removeSign() {
    this.sign = '';
    localStorage.removeItem('sign');
  }

  // 呼叫中心服务地址
  private socketUrl:string = '';
  // 获取呼叫中心服务地址
  getSocketUrl() {
    return this.socketUrl || localStorage.getItem('socketUrl');
  }
  // 设置呼叫中心服务地址
  setSocketUrl(socketUrl: string) {
    this.socketUrl = socketUrl;
    localStorage.setItem('socketUrl', socketUrl);
  }
  // 删除呼叫中心服务地址
  removeSocketUrl() {
    this.socketUrl = '';
    localStorage.removeItem('socketUrl');
  }
}
